# 2dxPlay
Play konami 2dx files from the command line.


Install with pip and run it from anywhere.  
`pip install 2dxPlay`

### Usage:
```
2dxplay infile.2dx
```
If the file contains more than one wav, it will play all tracks sequentially.  
Press Ctrl+C to pause and enter a track number to jump to, or `q` to quit.  

###Tip: Play any 2dx file just by double clicking on it:
Right click on a 2dx file, choose Open With > Look for another app on this PC.  
Navigate to your python installation where 2dxPlay.exe is installed. (I use python 3.7, so pip 
installed it in `%appdata%\Local\Programs\Python\Python37\Scripts`).  
Check the "Always use this app" box and profit.  

![img.png](img.png)